@@ -7,68 +7,10 @@ use Carp 'croak';
 use vars qw($VERSION @ISA);
 
 use Statistics::Zed 0.02;
-use Statistics::Sequences 0.03;
+use Statistics::Sequences 0.04;
 @ISA = qw(Statistics::Sequences);
 
-$VERSION = '0.031';
-
-#-----------------------------------------------
-sub test {
-#-----------------------------------------------
-
-   my $self = shift;
-   my $args = Class::OOorNO::coerce_array(@_);
-
-   $self->_check($args);
-   
-   my @data = @{$self->{'testdata'}};
-   
-   my $p = defined $args->{'prob'} ? delete $args->{'prob'} : 0.5;
-   my $q = 1 - $p;
-
-   my $w = defined $args->{'windows'} ? delete $args->{'windows'} : scalar @data;
-   
-   my ($obs_val, $exp_val, $var, $i, %states) = (0, 0);    
-
-   # Count the number of joins:
-   foreach ($i = 0; $i < @data; $i++) {
-       $states{$data[$i]}++;
-       if ($i and $data[$i] ne $data[$i - 1] ) {
-           $obs_val++;
-       }
-   }
-
-   return undef if scalar keys %states < 2;
-   #croak __PACKAGE__, '::test Less than two states were found in the data' if scalar keys %states < 2;
-   croak __PACKAGE__, '::test More than two states were found in the data' if scalar keys %states > 2;
-
-   $exp_val = 2 * ($w - 1) * $p * $q;
-    
-   $var = ( 4 * $w * $p * $q ) * (1 - ( 3 * $p * $q ) ) - ( ( 2 * $p * $q ) * (3 - ( 10 * $p * $q ) ) ); 
- 
-   if ($var) {
-       $self->_expound($obs_val, $exp_val, $var, $args);
-   }
-   else {
-       $self->_expire($obs_val, $exp_val, $args);
-   }
-
-   return $self;
-}
-
-#-----------------------------------------------
-sub dump {
-#-----------------------------------------------
-    my $self = shift;
-    my $args = ref $_[0] ? $_[0] : Class::OOorNO::coerce_array(@_);
-    $args->{'testname'} = 'Joins';
-    $self->SUPER::_dump_pass($args);
-    return $self;
- }
-
-1;
-
-__END__
+$VERSION = '0.04';
 
 =pod
 
@@ -118,12 +60,75 @@ Loads data anonymously or by name. See L<load|Statistics::Sequences/load> in the
 
 Test the currently loaded data for significance of the number of joins, given a probability of each state in the data array of B<prob>. This parameter is optionally defined in the call to C<test>; the default value is 0.5. Valid values are between 0 and 1, inclusive. In a classic signal detection task, for instance, where a state is either a hit or miss, the probability of each state is 0.5. In a classic ESP task, with 5 possible alternatives as targets on each trial, each state has a 1 in 5 chance of occurring, but we still test for a probability of 1/2 as the data will be have to be reduced to a dichotomous hit/miss format in order to be Runs- or Joins-tested.
 
+=cut
+
+#-----------------------------------------------
+sub test {
+#-----------------------------------------------
+
+   my $self = shift;
+   my $args = ref $_[0] ? $_[0] : {@_};
+
+   $self->_testdata_aref($args);
+   
+   my @data = @{$self->{'testdata'}};
+   
+   my $p = defined $args->{'prob'} ? delete $args->{'prob'} : 0.5;
+   my $q = 1 - $p;
+
+   my $w = defined $args->{'windows'} ? delete $args->{'windows'} : scalar @data;
+   
+   my ($obs_val, $exp_val, $var, $i, %states) = (0, 0);    
+
+   # Count the number of joins:
+   foreach ($i = 0; $i < @data; $i++) {
+       $states{$data[$i]}++;
+       if ($i and $data[$i] ne $data[$i - 1] ) {
+           $obs_val++;
+       }
+   }
+
+   return undef if scalar keys %states < 2;
+   #croak __PACKAGE__, '::test Less than two states were found in the data' if scalar keys %states < 2;
+   croak __PACKAGE__, '::test More than two states were found in the data: ' . join(' ', keys(%states)) if scalar keys %states > 2;
+
+   $exp_val = 2 * ($w - 1) * $p * $q;
+    
+   $var = ( 4 * $w * $p * $q ) * (1 - ( 3 * $p * $q ) ) - ( ( 2 * $p * $q ) * (3 - ( 10 * $p * $q ) ) ); 
+ 
+   if ($var) {
+       $self->_expound($obs_val, $exp_val, $var, $args);
+   }
+   else {
+       $self->_expire($obs_val, $exp_val, $args);
+   }
+
+   return $self;
+}
+
+
 =head2 dump
 
  $joins->dump(flag => '1|0', text => '0|1|2');
 
 Print Joins-test results to STDOUT. See L<dump|Statistics::Sequences/dump> in the Statistics::Sequences manpage for details.
 
+=cut
+
+#-----------------------------------------------
+sub dump {
+#-----------------------------------------------
+    my $self = shift;
+    my $args = ref $_[0] ? $_[0] : {@_};
+    $args->{'testname'} = 'Joins';
+    $self->SUPER::_dump_pass($args);
+    return $self;
+ }
+
+1;
+
+__END__
+
 =head1 EXAMPLE
 
 Here the problem is to assess the degree of consistency of ESP scoring from the number of hits obtained in each of 200 runs of 25 trials each. The number of hits expected on the basis of chance is 5 per run. To test for sustained high or low scoring sequences, a join is defined as the point at which a score on one side of this expectation value is followed by a score on the other side. Ignoring scores equalling the expectation value of 5, the probability of a join is 1/2, or 0.5 (the default value to L<test|test>), assuming that, say, a score of 4 is as likely as a score of 6, and anything greater than a deviation of 5 (from 5) is improbable (or impossible). A meaningful result would obtain when the number of joins observed was below the number expected; we ignore the converse (and perverse) situation.
@@ -147,7 +152,7 @@ Here the problem is to assess the degree of consistency of ESP scoring from the
   my $seq = Statistics::Sequences->new();
   $seq->load(@scores);
   $seq->cut(value => $expected_hits, equal => 0);
-  $seq->test('joins', tails => 1, ccorr => 1)->dump(text => 1, flag => 1);
+  $seq->test(what => 'joins', tails => 1, ccorr => 1)->dump(text => 1, flag => 1);
   # prints, e.g., Joins: expected = 79.00, observed = 67.00, z = -1.91, p = 0.028109*
 
 =head1 REFERENCES
@@ -174,7 +179,7 @@ See CHANGES in installation dist for revisions.
 
 =over 4
 
-=item Copyright (c) 2006-2009 Roderick Garton
+=item Copyright (c) 2006-2010 Roderick Garton
 
 rgarton AT cpan DOT org
 
